document.addEventListener('DOMContentLoaded', function () {
	//Esconde o cabeçalho automaticamente ao rolar para baixo e exibe o botão "topo"
	el_autohide = document.querySelector('.fixed-top');

	// definindo as varáveis fora do if
	var last_scroll_top = 0;
	var button_top = document.getElementById('cc-scroll-to-top');
	var navbar_height = document.querySelector('.navbar').offsetHeight;

	if (el_autohide) {
		window.addEventListener('scroll', function () {
			let scroll_top = window.scrollY;
			if (scroll_top < last_scroll_top) {
				el_autohide.classList.remove('cc-scrolled-down');
				el_autohide.classList.add('cc-scrolled-up');
			} else {
				el_autohide.classList.remove('cc-scrolled-up');
				el_autohide.classList.add('cc-scrolled-down');
			}
			if (scroll_top < navbar_height) {
				el_autohide.classList.remove('cc-white-header');
				el_autohide.classList.add('cc-transparent-header');
			} else {
				el_autohide.classList.remove('cc-transparent-header');
				el_autohide.classList.add('cc-white-header');
			}
			// Esconde o botão topo
			if (scroll_top > 20) {
				button_top.style.display = 'block';
			} else {
				button_top.style.display = 'none';
			}
			last_scroll_top = scroll_top;
		});
	}

	if (button_top) {
		//Rola a página para o início ao clicar no botão "topo"
		button_top.onclick = function () {
			document.body.scrollTop = 0; // For Safari
			document.documentElement.scrollTop = 0; // For Chrome, Firefox, IE and Opera
		};
	}

	//Rola a página para a primeira quebra
	explorar = document.querySelector('.cc-btn-explorar');

	if (explorar) {
		let top = document.querySelector('.cc-cover').offsetHeight;

		explorar.onclick = function () {
			window.scrollTo(0, top);
		};
	}

	//Scripts da modal e da barra inferior de botões (índice)
	let indice = document.getElementById('indice');

	if (indice) {
		//inicia modal do Bootstrap nas páginas dos artigos e cientistas
		var itemModal = document.getElementById('cc-item-modal');

		itemModal.addEventListener('show.bs.modal', function (event) {
			// Button that triggered the modal
			var trigger = event.relatedTarget;
			// Extract info from data-bs-* attributes
			var content = trigger.getAttribute('data-bs-content');

			// If necessary, you could initiate an AJAX request here
			// and then do the updating in a callback.
			//
			// Update the modal's content.
			var modalTitle = itemModal.querySelector(
				'.modal-header h4 span.cc-modal-title'
			);
			var modalBody = itemModal.querySelector('.modal-body');

			modalTitle.textContent = trigger.textContent;
			modalBody.innerHTML = document.getElementById(content).innerHTML;
		});

		//Fixa a barra de botões das páginas de artigos e cientistas
		//no rodapé da tela até o rodapé da página aparecer.
		let rodape;

		window.addEventListener(
			'load',
			event => {
				rodape = document.querySelector('.site-footer-container');
				createRodapeObserver();
			},
			false
		);

		function createRodapeObserver() {
			let rodapeObserver;

			let options = {
				root: null,
				rootMargin: '0px',
				threshold: 0
			};

			rodapeObserver = new IntersectionObserver(stickIndice, options);
			rodapeObserver.observe(rodape);
		}

		const stickIndice = entries => {
			entries.forEach(entry => {
				if (entry.isIntersecting) {
					indice.style.position = 'static';
				} else {
					indice.style.position = 'fixed';
				}
			});
		};
	}

	/**
	 * Manipula a mudança no tamanho da tela e ajusta o comportamento das colunas de acordo.
	 *
	 * @param {MediaQueryListEvent} event - O evento disparado quando a media query é correspondida ou não.
	 * @param {HTMLElement} element - O elemento pai que contém as colunas.
	 */
	function stickShorterColumn(element) {
		// Define a media query para telas com largura superior a 782px
		const mediaQuery = window.matchMedia('(min-width: 782px)');

		function handleScreenChange(event, element) {
			// Obtém os elementos das colunas
			aside = element.querySelector('.cc-artigo-aside');
			main = element.querySelector('.cc-artigo-main');

			if (event.matches) {
				// Obtém os estilos computados da coluna aside
				aside_cs = getComputedStyle(aside);
				aside_padding_y =
					parseFloat(aside_cs.paddingTop) +
					parseFloat(aside_cs.paddingBottom);
				aside_height = aside.offsetHeight - aside_padding_y;
				aside_last_img_height = element.querySelector(
					'.cc-artigo-aside figure:last-of-type'
				).offsetHeight;

				// Obtém a altura da coluna principal
				main_height = main.offsetHeight;

				// Verifica se a altura da coluna principal é diferente da altura da coluna aside
				if (main_height != aside_height) {
					if (main_height > aside_height) {
						// Se a coluna principal for mais alta, torna a coluna aside sticky e a posiciona na parte inferior
						aside.style.position = 'sticky';
						aside.style.top =
							aside_last_img_height - aside_height + 'px';
					} else {
						// Se a coluna aside for mais alta, torna a coluna principal sticky e a posiciona no final da tela
						main.style.position = 'sticky';
						main.style.top =
							window.innerHeight - 78 - main_height + 'px';
					}
				}
			} else {
				// Redefine os estilos das colunas quando a media query não corresponde
				aside.removeAttribute('style');
				main.removeAttribute('style');
			}
		}

		// Chama a função handleScreenChange inicialmente
		handleScreenChange(mediaQuery, element);
		// Adiciona um event listener para a media query para lidar com futuras mudanças
		mediaQuery.addEventListener('change', handleScreenChange);
	}

	/**
	 * Cria um MutationObserver para o ID do elemento especificado.
	 * Isso permite manipular conteúdo carregado dinamicamente via JSON do Omeka.
	 * @param {string} elementId - O ID do elemento a ser observado.
	 */
	function createObserverForElement(elementId) {
		// Obter o elemento com o ID especificado
		let element = document.getElementById(elementId);

		// Verificar se o elemento existe e é do tipo ELEMENT_NODE
		if (element && element.nodeType === Node.ELEMENT_NODE) {
			// Opções para o MutationObserver
			const options = {
				childList: true,
				subtree: true
			};

			// Criar o MutationObserver
			const observer = new MutationObserver(mutations => {
				// Lidar com cada mutação
				for (let mutation of mutations) {
					// Verificar se o tipo de mutação é 'childList'
					if (mutation.type === 'childList') {
						// Chamar a função para fixar a coluna mais curta
						stickShorterColumn(element);
					}
				}
			});

			// Iniciar a observação do elemento
			observer.observe(element, options);
		}
	}

	/**
	 * Adiciona listeners de evento para cada div específica quando a janela é carregada.
	 * Ele utiliza a função createObserverForElement para criar observadores para os elementos com os IDs:
	 * 'biografia' (página do cientista),
	 * 'o-que-e', 'como-e-feita' e 'qual-a-importancia' (página de artigos).
	 */
	// .
	window.addEventListener(
		'load',
		() => {
			createObserverForElement('biografia');
			createObserverForElement('o-que-e');
			createObserverForElement('como-e-feita');
			createObserverForElement('qual-a-importancia');
		},
		false
	);

	//Imprime os encartes
	button_print = document.getElementById('cc-botao-imprimir');

	if (button_print) {
		button_print.onclick = function () {
			document.body.classList.add('cc-print-encarte');
			window.print();
			document.body.classList.remove('cc-print-encarte');
		};
	}

	//Botões da busca avançada
	search_results = document.getElementById('cc-resultados-da-busca');
	search_filters = document.getElementById('cc-filtros');
	button_grid = document.getElementById('cc-botao-grid');
	button_list = document.getElementById('cc-botao-lista');
	button_filters = document.getElementById('cc-botao-filtros');

	if (search_results) {
		//botão para exibir resultados em grade
		if (button_grid) {
			button_grid.onclick = function () {
				search_results.classList.remove('cc-lista-1');
				search_results.classList.add('cc-lista-3');
				button_list.classList.remove('active');
				this.classList.add('active');
			};
		}

		//botão para exibir resultados em lista
		if (button_list) {
			button_list.onclick = function () {
				search_results.classList.remove('cc-lista-3');
				search_results.classList.add('cc-lista-1');
				button_grid.classList.remove('active');
				this.classList.add('active');
			};
		}

		if (button_filters) {
			//Esconde os filtros em telas menores que 782px de
			if (window.matchMedia('(max-width: 781px)').matches) {
				search_filters.style.display = 'none';
				search_filters.classList.add('oculto');
			}

			const is_hidden = () => search_filters.classList.contains('oculto');

			search_filters.addEventListener('transitionend', function () {
				if (is_hidden()) {
					search_filters.style.display = 'none';
				}
			});

			button_filters.addEventListener('click', function () {
				if (is_hidden()) {
					search_filters.style.removeProperty('display');
					setTimeout(
						() => search_filters.classList.remove('oculto'),
						0
					);
					this.classList.add('active');
				} else {
					search_filters.classList.add('oculto');
					this.classList.remove('active');
				}
			});
		}
	}

	//botão de fullscreen dos jogos
	button_fullscreen = document.getElementById('cc-botao-fullscreen');

	if (button_fullscreen) {
		//abre o iframe do jogo em fullscreen
		button_fullscreen.onclick = function () {
			//Pega o iframe do jogo
			var elem = document.querySelector('.getod-iframe');

			//prefixos para os browsers que não suportam o método requestFullscreen
			if (elem.requestFullscreen) {
				elem.requestFullscreen();
			} else if (elem.webkitRequestFullscreen) {
				/* Safari */
				elem.webkitRequestFullscreen();
			} else if (elem.msRequestFullscreen) {
				/* IE11 */
				elem.msRequestFullscreen();
			}
		};
	}

	//focus no campo de busca
	var myModal = document.getElementById('busca')
	var myInput = document.getElementById('search_term')

	myModal.addEventListener('shown.bs.modal', function () {
		myInput.focus()
	})

});
// DOMContentLoaded  end
